% Code Author: Moh Sabbir Saadat
% Institution: University of South Carolina
% Last update date: September 24, 2021
% Website: https://cse.sc.edu/~msaadat/

% this function returns the base profile of the throughput of an antenna
function throughput_profile = CreateThroughputProfile(antenna_no)
global folder_currentdissipation  tx_max data_length
filename = fullfile(folder_currentdissipation, strcat('dissipation_',num2str(antenna_no)));

throughput_profile = ExtractThroughput(filename);

% determine and negate the idle period
start = 1;
while throughput_profile(start) == 0
    start = start+1;
end
throughput_profile(1:start-1) = [];

% cut out the trailing non-transmitting portion
if length(throughput_profile) > tx_max
    throughput_profile(tx_max+1:end) = [];
end

% slice off the trailing end to create data of fixed length
if length(throughput_profile) > data_length
    throughput_profile(data_length+1:end) = [];
elseif length(throughput_profile) < data_length
    while length(throughput_profile) ~= data_length
        throughput_profile = [throughput_profile; NaN];
    end
end

% % you can choose to visualize the throughput profile by uncommenting this
% % block, unless there is any NaN
% if ~any(isnan(throughput_profile))
%     %% plot to test
%     figure;
%     plot(throughput_profile)
%     grid on
% end

end