% Code Author: Moh Sabbir Saadat
% Institution: University of South Carolina
% Last update date: September 24, 2021
% Website: https://cse.sc.edu/~msaadat/

clearvars -except comb_no

global data_length beam_latency folder_currentdissipation
globalParams;

filename = fullfile(folder_scheduling, 'PossibleAntennaSchedule.csv');
all_schedules = readmatrix(filename);
filename = fullfile(folder_scheduling, 'PossibleDataCombinations.csv');
dataComb_full = readmatrix(filename);
data_comb = dataComb_full(comb_no, :);
clear dataComb_full;

no_antenna2 = size(data_comb, 2);
exp_window2 = size(all_schedules, 2);
if exp_window2 ~= exp_window || no_antenna2 ~= no_antenna
    fprintf('Parameter values do not match. \n')
    return;
else
    clear exp_window2 no_antenna2
end
beam_latency = full_latency(3,1); % interpolated: beam alignment latency: 32 element, IEEE802.11ad

disp('Copying data files...')
% copying the appropriate data files to the current dissipation directory
if ~exist(folder_currentdissipation, 'dir')
    mkdir(folder_currentdissipation);
end
for j = 1:no_antenna
    
    % bf (throughput) files
    filename_source = fullfile(folder_dissipation, strcat('dissipation_', num2str(tx_max),'_', num2str(data_comb(j)),'_bf'));
    filename_destination = fullfile(folder_currentdissipation, strcat('dissipation_', num2str(j),'_bf'));
    copyfile(filename_source, filename_destination)
    
    % temperature files
    filename_source = fullfile(folder_dissipation, strcat('dissipation_', num2str(tx_max),'_', num2str(data_comb(j)),'_temp'));
    filename_destination = fullfile(folder_currentdissipation, strcat('dissipation_', num2str(j),'_temp'));
    copyfile(filename_source, filename_destination)
end

% extract the blockage configuration and link lengths
disp('Extracting the blockage configuration and link lengths...')
filename = fullfile(folder_scheduling, 'channel_status.csv');
channel_status = readmatrix(filename);
filename = fullfile(folder_scheduling, 'link_lengths.csv');
tx_time = readmatrix(filename);

% create the base temperature profile as well as determine idle temperature for each set of antennas
disp('Creating the base temperature profile and throughput profile...')
base_profile = [];
idle_temp = [];
for i = 1:no_antenna
    [prof, idle] = CreateTemperatureProfile(i); % CreateTemperatureProfile(tx_time, i) - since tx_time is declared as a global variable...
    % we refrain from passing
    % it as an input
    base_profile = [base_profile prof];
    idle_temp = [idle_temp idle];
end
clear prof idle
% create the throughput profiles
throughput_profile = [];
for i = 1:no_antenna
    % create throughput profile for antenna i based on the tx times given
    % in tx_time
    throughput_profile = [throughput_profile CreateThroughputProfile(i)];
end

% generate look-ahead schedules
create_look_ahead;

% probe-and-switch
probe_and_switch;