% Code Author: Moh Sabbir Saadat
% Institution: University of South Carolina
% Last update date: September 24, 2021
% Website: https://cse.sc.edu/~msaadat/

% Create look-ahead-schedule list
disp('Generating the look ahead schedule list...')
temp_series_schedule = [];
lookAhead_list = [];
transmit_time_schedule = [];
temperature_before = Inf;
sorted_temp = []; % [peak_temp index]

for i = 1:length(all_schedules(:,1))
    % for schedule no i
    ant_sched = all_schedules(i,:);
    current_temp = idle_temp;
    stat = false([no_antenna, 1]);
    transmit_time = [];
    throughput_series = [];
    temp_series = [];
    
    for j = 1:exp_window
        
        % transmitting antenna - ant_sched(j)
        transmit_time = [transmit_time tx_time(ant_sched(j), j)+1]; % tx_time is a (no_antenna x exp_window) array
        frac = transmit_time(j) - floor(transmit_time(j));
        % throughput
        stat(ant_sched(j)) = true;
        thr_profile = throughput_profile(:, ant_sched(j));
        throughput = sum(thr_profile(1:floor(transmit_time(j))));
        diff_thr = (frac/2)*(thr_profile(floor(transmit_time(j)))+thr_profile(ceil(transmit_time(j))));
        throughput = throughput + diff_thr;
        throughput_series  = [throughput_series; throughput/transmit_time(j)];
        % temperature
        temp_prof = base_profile(:, ant_sched(j)) + current_temp(ant_sched(j));
        current_temp(ant_sched(j)) = temp_prof(floor(transmit_time(j)));
        diff_temp = frac*(temp_prof(ceil(transmit_time(j)))-temp_prof(floor(transmit_time(j))));
        current_temp(ant_sched(j)) = current_temp(ant_sched(j)) + diff_temp;
        
        % dissipating - {1:4}-ant_sched(j)
        for m = 1:no_antenna
            if m ~= ant_sched(j)
                if stat(m)
                    temp_prof = base_profile(:,m)-base_profile(tx_max,m);
                    temp_prof(1:tx_max) = [];
                    temp_prof = temp_prof + current_temp(m);
                    current_temp(m) = temp_prof(floor(transmit_time(j)));
                    diff_temp = frac*(temp_prof(ceil(transmit_time(j))) - temp_prof(floor(transmit_time(j))));
                    current_temp(m) = current_temp(m) + diff_temp;
                end
            end
        end
        
        temp_series = [temp_series; current_temp];
    end
    
    if max(max(temp_series)) < temperature_before
        temp_series_schedule = temp_series;
        lookAhead_list = ant_sched;
        transmit_time_schedule = sum(transmit_time);
        throughput_series_schedule = throughput_series;
        throughput_schedule = sum(throughput_series.*transmit_time.')/transmit_time_schedule;
        temperature_before = max(max(temp_series));
    end
    
    sorted_temp = [sorted_temp; max(max(temp_series))];
end

% sort
[sorted_temp, order] = sort(sorted_temp);
sorted_schedules = all_schedules(order, :);